@@ -3,7 +3,8 @@
 
 """Import core names of FastSeq"""
 
-from fastseq.logging.logging_utils import set_log_level
-set_log_level()
+from fastseq.logging import set_default_log_level
+set_default_log_level()
 
+import fastseq.models  # pylint: disable=wrong-import-position
 import fastseq.optimizer  # pylint: disable=wrong-import-position
